==> haskell-tasty-th-0.1.7-147-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-6jT8mqKauLL2L5dZgXix4q
key:                  tasty-th-0.1.7-6jT8mqKauLL2L5dZgXix4q
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  6a3c3045355fd2d0d1125792880c0069
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-8.10.2/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/tasty-th-0.1.7
hs-libraries:         HStasty-th-0.1.7-6jT8mqKauLL2L5dZgXix4q
depends:
    base-4.14.1.0 haskell-src-exts-1.23.1-2WeLoDeRtLpB9ADYWuNDkB
    tasty-1.3.1-JHYy5w6iC5WLRwa65c7kKk template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-th-0.1.7-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-th
version:              0.1.7
visibility:           public
id:                   tasty-th-0.1.7-3YU9RN9bMHV5FU9fqNQWDX
key:                  tasty-th-0.1.7-3YU9RN9bMHV5FU9fqNQWDX
license:              BSD-3-Clause
maintainer:           Benno Fünfstück <benno.fuenfstueck@gmail.com>
author:               Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage:             http://github.com/bennofs/tasty-th
synopsis:             Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.

category:             Testing
abi:                  fae6c9de540c3ebe271cd8449c575377
exposed:              True
exposed-modules:      Test.Tasty.TH
import-dirs:          /usr/lib/ghc-8.10.2/site-local/tasty-th-0.1.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/tasty-th-0.1.7
hs-libraries:         HStasty-th-0.1.7-3YU9RN9bMHV5FU9fqNQWDX
depends:
    base-4.14.1.0 haskell-src-exts-1.23.1-Df4neTz9rvf7rPw0nP9Mv0
    tasty-1.3.1-96kNLJA5m8Gw3clKGKAbg template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html:         /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
